@@ -1,31 +1,20 @@
-# $Id: SAX.pm 776 2009-02-06 11:12:56Z pajas $
-#
-# This is free software, you may use it and distribute it under the same terms as
-# Perl itself.
-#
-# Copyright 2001-2003 AxKit.com Ltd., 2002-2006 Christian Glahn, 2006-2009 Petr Pajas
-#
-#
+# $Id: SAX.pm,v 1.1 2002/05/20 10:38:42 phish Exp $
 
 package XML::LibXML::SAX;
 
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = "1.69_2"; # VERSION TEMPLATE: DO NOT CHANGE
+$VERSION = '0.01';
 
 use XML::LibXML;
 use XML::SAX::Base;
 
-use base qw(XML::SAX::Base);
+@ISA = qw(XML::SAX::Base);
 
 use Carp;
 use IO::File;
 
-sub CLONE_SKIP {
-  return $XML::LibXML::__threads_shared ? 0 : 1;
-}
-
 sub _parse_characterstream {
     my ( $self, $fh ) = @_;
     # this my catch the xml decl, so the parser won't get confused about
@@ -38,37 +27,32 @@ sub _parse_bytestream {
     $self->{ParserOptions}{LibParser}      = XML::LibXML->new;
     $self->{ParserOptions}{ParseFunc}      = \&XML::LibXML::parse_fh;
     $self->{ParserOptions}{ParseFuncParam} = $fh;
-    $self->_parse;
-    return $self->end_document({});
+    return $self->_parse;
 }
 
 sub _parse_string {
     my ( $self, $string ) = @_;
-#    $self->{ParserOptions}{LibParser}      = XML::LibXML->new;
-    $self->{ParserOptions}{LibParser}      = XML::LibXML->new()     unless defined $self->{ParserOptions}{LibParser};
+    $self->{ParserOptions}{LibParser}      = XML::LibXML->new;
     $self->{ParserOptions}{ParseFunc}      = \&XML::LibXML::parse_string;
     $self->{ParserOptions}{ParseFuncParam} = $string;
-    $self->_parse;
-    return $self->end_document({});
+    return $self->_parse;
 }
 
 sub _parse_systemid {
     my $self = shift;
+    my $fh = IO::File->new(shift);
     $self->{ParserOptions}{LibParser}      = XML::LibXML->new;
-    $self->{ParserOptions}{ParseFunc}      = \&XML::LibXML::parse_file;
-    $self->{ParserOptions}{ParseFuncParam} = shift;
-    $self->_parse;
-    return $self->end_document({});
+    $self->{ParserOptions}{ParseFunc}      = \&XML::LibXML::parse_fh;
+    $self->{ParserOptions}{ParseFuncParam} = $fh;
+    return $self->_parse;
 }
 
 sub parse_chunk {
     my ( $self, $chunk ) = @_;
     $self->{ParserOptions}{LibParser}      = XML::LibXML->new;
     $self->{ParserOptions}{ParseFunc}      = \&XML::LibXML::parse_xml_chunk;
-    $self->{ParserOptions}{LibParser}->{IS_FILTER}=1; # a hack to prevent parse_xml_chunk from issuing end_document
     $self->{ParserOptions}{ParseFuncParam} = $chunk;
-    $self->_parse;
-    return;
+    return $self->_parse;
 }
 
 sub _parse {
@@ -76,22 +60,13 @@ sub _parse {
     my $args = bless $self->{ParserOptions}, ref($self);
 
     $args->{LibParser}->set_handler( $self );
-    eval {
-      $args->{ParseFunc}->($args->{LibParser}, $args->{ParseFuncParam});
-    };
+    $args->{ParseFunc}->($args->{LibParser}, $args->{ParseFuncParam});
 
     if ( $args->{LibParser}->{SAX}->{State} == 1 ) {
         croak( "SAX Exception not implemented, yet; Data ended before document ended\n" );
     }
 
-    # break a possible circular reference
-    $args->{LibParser}->set_handler( undef );
-    if ( $@ ) {
-        croak $@;
-    }
-    return;
-}
-
+    return $self->end_document({}); }
 
 1;
 
